ac_extract_df() is the data-frame form of ac_extract(). It is useful when
you want one row per match instead of one list element per document.
Usage
ac_extract_df(
ac,
doc,
...,
overlapping = FALSE,
na = c("omit", "keep", "error")
)Arguments
- ac
An
<ac_automaton>object created byac_build().- doc
A character vector of documents to search.
- ...
Must be empty. This is used to require optional arguments to be supplied by name.
- overlapping
Default is
FALSE. IfTRUE, extract overlapping matches. This is only supported whenacwas built withmatch_kind = "standard".- na
How to handle
NAdocuments."omit"drops missing documents (default);"keep"returns one row with missing result columns for each missing document;"error"fails.