ac_locate_df() is the data-frame form of ac_locate(). It is useful when
you want one row per match instead of one list element per document.
Usage
ac_locate_df(ac, doc, overlapping = FALSE, na = c("omit", "keep", "error"))Arguments
- ac
An
<ac_automaton>object created byac_build().- doc
A character vector of documents to search.
- overlapping
Default is
FALSE. IfTRUE, report overlapping matches. This is only supported whenacwas built withmatch_kind = "standard".- na
How to handle
NAdocuments."omit"drops missing documents (default);"keep"returns one row with missing result columns for each missing document;"error"fails.